@@ -1,10 +1,6 @@
 .onLoad <- function(libname, pkgname) {
-  # set Java parameters if none specified
-  # if (is.null(getOption("java.parameters"))) {
-    options(java.parameters = "-Xmx4g")
-  # }
-  # Check that Java version is at least 8
   .jinit()
+  # Check that Java version is at least 8
   jv <- .jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
   if(substr(jv, 1L, 2L) == "1.") {
     jvn <- as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
